/*
 * Segment 2 (KEx),  SWE2.4 Email/Fax/SMS
 * Copyright (C) 2007, 2015 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.emailfaxsms.voice.sender;

import de.bitctrl.sibacop.client.AbstractRequest;
import de.bitctrl.sibacop.client.Connection;
import de.bitctrl.sibacop.client.swis_sh.TextToSpeechToPhoneRequest;
import de.bsvrz.kex.emailfaxsms.voip.KexVoIPSender;
import de.bsvrz.sys.funclib.debug.Debug;

/**
 * Versendet Sprachnachrichten.
 *
 * @author BitCtrl Systems GmbH, Steffen Gieseler
 * @version $Id$
 */
public class KexVoiceSender extends KexVoIPSender {

	/**
	 * LOGGER.
	 */
	protected static final Debug LOGGER = Debug.getLogger();

	/**
	 * Return-Codes:
	 * 
	 * Text to speech to phone =======================
	 * 
	 * Return codes <br>
	 * ============ <br>
	 * 100: Continue <br>
	 * 200: OK <br>
	 * 211: Answered <br>
	 * 212: Completed <br>
	 * 213: Confirmed <br>
	 * 400: Bad Request <br>
	 * 401: Method Not Implemented <br>
	 * 402: Unknown Header <br>
	 * 500: Internal Server Error <br>
	 * 501: Request handler terminated unexpectedly with exit code %d <br>
	 * 502: Request handler returned without response code 503: Request handler died
	 */

	/**
	 * Standardkonstruktor.
	 *
	 * @param host
	 *            VoIP-Sender Host
	 * @param port
	 *            VoIP-Sender Host
	 * 
	 * @throws Exception
	 *             bei Fehlern
	 */
	public KexVoiceSender(final String host, final int port) throws Exception {
		super(host, port);

		KexVoiceSender.LOGGER.fine("VoIP-Sprachnachricht-Sender Initialisierung komplett");
	}

	protected AbstractRequest<?> erzeugeRequest(final Connection connection, final String empfaenger, final String text) {
		final TextToSpeechToPhoneRequest req = connection.createRequest(TextToSpeechToPhoneRequest.class);
		req.setRcptNumber(empfaenger);
		req.appendMessageText(text);

		return req;
	}

	@Override
	protected boolean isOkResponse(final int responseCode) {
		return responseCode == KexVoIPSender.VOIP_RESPONSE_CODE_COMPLETED;
	}

}
