/*
 * Segment 2 (KEx),  SWE2.4 Email/Fax/SMS
 * Copyright (C) 2007, 2015 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */


package de.bsvrz.kex.emailfaxsms.voipfax.texter;

import de.bitctrl.sibacop.client.AbstractRequest;
import de.bitctrl.sibacop.client.Connection;
import de.bitctrl.sibacop.client.swis_sh.TextToFaxRequest;
import de.bsvrz.kex.emailfaxsms.voip.KexVoIPSender;
import de.bsvrz.sys.funclib.debug.Debug;

/**
 * Versendet Fax-Nachrichten &uuml;ber VoIP.
 *
 * @author BitCtrl Systems GmbH, Steffen Gieseler
 * @version $Id$
 */
public class KexVoIPFaxSender extends KexVoIPSender {

	/**
	 * LOGGER.
	 */
	protected static final Debug LOGGER = Debug.getLogger();


	
	/**
	 * Return-Codes:
	 * 
	 * Text to facsimile
	 * =================
	 *  
	 * Return codes
	 * ============
	 * 100: Continue
	 * 110: HylaFAX message
	 * 200: OK
	 * 400: Bad Request
	 * 401: Method Not Implemented
	 * 402: Unknown Header
	 * 410: Send facsimile failed
	 * 500: Internal Server Error
	 * 501: Request handler terminated unexpectedly with exit code %d
	 * 502: Request handler returned without response code
	 * 503: Request handler died
	 */

	/**
	 * Standardkonstruktor.
	 *
	 * @param host
	 *            VoIP-Sender Host
	 * @param port
	 *            VoIP-Sender Host
	 * 
	 * @throws Exception
	 *             bei Fehlern
	 */
	public KexVoIPFaxSender(final String host, final int port) throws Exception {
		super(host, port);
		KexVoIPFaxSender.LOGGER.fine("VoIP-Fax-Sender Initialisierung komplett");
	}

	
	protected AbstractRequest<?> erzeugeRequest(final Connection connection, final String empfaenger, final String text) {
		final TextToFaxRequest req = connection.createRequest(TextToFaxRequest.class);
		req.setRcptNumber(empfaenger);
		req.appendMessageText(text);
		
		return req;
	}


	@Override
	protected boolean isOkResponse(final int responseCode) {
		return responseCode == KexVoIPSender.VOIP_RESPONSE_CODE_NO_ERROR;
	}
}
